Core Modules
============
The MetaWear firmware comes with several powerful features that enable developers to fine-tune their board configuration for specific use cases.  
Outside of the :doc:`sensor_fusion` module (MetaMotion only), all of these features are available on every board.

.. toctree::
    :hidden:
    :maxdepth: 1

    dataprocessor
    logging
    macro
    sensor_fusion
    settings
    timer
